'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _fargs = require('fargs');

var _fargs2 = _interopRequireDefault(_fargs);

var _autocomplete = require('./autocomplete');

var _autocomplete2 = _interopRequireDefault(_autocomplete);

var _clickAnalytics = require('./clickAnalytics');

var _compile = require('./compile');

var _compile2 = _interopRequireDefault(_compile);

var _getCurrentLocale = require('./getCurrentLocale');

var _getCurrentLocale2 = _interopRequireDefault(_getCurrentLocale);

var _instantsearch = require('./instantsearch');

var _instantsearch2 = _interopRequireDefault(_instantsearch);

var _templates = require('./templates');

var _templates2 = _interopRequireDefault(_templates);

var _translations = require('./translations');

var _translations2 = _interopRequireDefault(_translations);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function hitsPerPageValidator(val) {
  return val >= 1 && val <= 20 || 'should be between 1 and 20';
}
function instantsearchPage() {
  return window.location.pathname.match(/\/search$/) !== null;
}
var optionsStructure = {
  required: true,
  type: 'Object',
  children: {
    analytics: { type: 'boolean', value: true },
    applicationId: { type: 'string', required: true },
    apiKey: { type: 'string', required: true },
    autocomplete: {
      type: 'Object',
      value: {},
      children: {
        enabled: { type: 'boolean', value: true },
        inputSelector: { type: 'string', value: '#query' },
        hitsPerPage: {
          type: 'number',
          value: 5,
          validators: [hitsPerPageValidator]
        }
      }
    },
    baseUrl: { type: 'string', value: '/hc/' },
    color: { type: 'string', value: '#158EC2' },
    clickAnalytics: { type: 'boolean', value: false },
    debug: { type: 'boolean', value: false },
    locale: { type: 'string' },
    highlightColor: { type: 'string' },
    indexPrefix: { type: 'string', value: 'zendesk_' },
    instantsearch: {
      type: 'Object',
      value: {},
      children: {
        enabled: { type: 'boolean', value: true },
        hitsPerPage: { type: 'number', value: 20 },
        paginationSelector: { type: 'string', value: '.pagination' },
        reuseAutocomplete: { type: 'boolean', value: false },
        hideAutocomplete: { type: 'boolean', value: true },
        selector: { type: 'string', value: '.search-results' },
        tagsLimit: { type: 'number', value: 15 },
        useEditedAt: { type: 'boolean', value: false },
        showHitsFullPath: { type: 'boolean', value: false }
      }
    },
    instantsearchPage: { type: 'function', value: instantsearchPage },
    poweredBy: { type: 'boolean', value: true },
    responsive: { type: 'boolean', value: true },
    subdomain: { type: 'string', required: true },
    indexName: { type: 'string', value: '' },
    templates: {
      type: 'Object',
      value: {},
      children: {
        autocomplete: { type: 'Object', value: {} },
        instantsearch: { type: 'Object', value: {} }
      }
    },
    translations: { type: 'Object', value: {} }
  }
};

var AlgoliasearchZendeskHC = function () {
  function AlgoliasearchZendeskHC() {
    _classCallCheck(this, AlgoliasearchZendeskHC);

    var options = (0, _fargs2.default)().check('algoliasearchZendeskHC').arg('options', optionsStructure)
    // eslint-disable-next-line prefer-rest-params
    .values(arguments)[0];

    options.highlightColor = options.highlightColor || options.color;

    this.search = (options.instantsearch.enabled && options.instantsearchPage() ? _instantsearch2.default : _autocomplete2.default)(options);

    AlgoliasearchZendeskHC.instances.push(this.search);

    if (options.clickAnalytics) {
      (0, _clickAnalytics.initInsights)(options);
      (0, _clickAnalytics.extendWithConversionTracking)(this.search, options);
    }

    // once the DOM is initialized
    if (document.readyState === 'complete' || document.readyState === 'interactive') {
      this.render(options);
    } else {
      document.addEventListener('DOMContentLoaded', this.render.bind(this, options));
    }
  }

  _createClass(AlgoliasearchZendeskHC, [{
    key: 'enableDebugMode',
    value: function enableDebugMode() {
      if (!this.search.enableDebugMode) return;
      this.search.enableDebugMode();
    }
  }, {
    key: 'render',
    value: function render(options) {
      options.locale = options.locale || (0, _getCurrentLocale2.default)();
      (0, _translations2.default)(options);
      (0, _templates2.default)(options);
      this.search.render(options);
    }
  }]);

  return AlgoliasearchZendeskHC;
}();

AlgoliasearchZendeskHC.instances = [];
AlgoliasearchZendeskHC.compile = _compile2.default;
AlgoliasearchZendeskHC.trackConversion = function (articleID) {
  var instances = AlgoliasearchZendeskHC.instances;
  if (instances.length === 0) {
    throw new Error('AlgoliasearchZendeskHCError: Trying to track conversion without an instance loaded');
  }
  if (instances.length > 1) {
    throw new Error('AlgoliasearchZendeskHCError: Trying to track conversion with multiple instances loaded - Use the instance method directly');
  }

  if (articleID === undefined) {
    if (window.location.pathname.indexOf('/articles/') === -1) {
      throw new Error('AlgoliasearchZendeskHCError: Calling trackConversion without an articleID on a non-article page');
    }
    try {
      articleID = window.location.pathname.split('/')[4].split('-')[0];
    } catch (err) {
      throw new Error('AlgoliasearchZendeskHCError: Failed to extract the article articleID from the URL');
    }
  }

  instances[0].trackConversion(articleID);
};

exports.default = AlgoliasearchZendeskHC;