'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }(); // Small hack to remove verticalAlign on the input
// Makes IE11 fail though


var _algoliasearch = require('algoliasearch');

var _algoliasearch2 = _interopRequireDefault(_algoliasearch);

var _autocomplete = require('autocomplete.js');

var _autocomplete2 = _interopRequireDefault(_autocomplete);

var _utils = require('autocomplete.js/src/common/utils');

var _utils2 = _interopRequireDefault(_utils);

var _zepto = require('autocomplete.js/zepto');

var _zepto2 = _interopRequireDefault(_zepto);

var _addCSS = require('./addCSS');

var _addCSS2 = _interopRequireDefault(_addCSS);

var _clickAnalytics = require('./clickAnalytics');

var _removeCSS = require('./removeCSS');

var _removeCSS2 = _interopRequireDefault(_removeCSS);

var _stopwords = require('./stopwords');

var _stopwords2 = _interopRequireDefault(_stopwords);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

if (!_utils2.default.isMsie()) {
  var css = require('autocomplete.js/src/autocomplete/css');
  delete css.input.verticalAlign;
  delete css.inputWithNoHint.verticalAlign;
}

var XS_WIDTH = 400;
var SM_WIDTH = 600;

var Autocomplete = function () {
  function Autocomplete(_ref) {
    var applicationId = _ref.applicationId,
        apiKey = _ref.apiKey,
        _ref$autocomplete = _ref.autocomplete,
        enabled = _ref$autocomplete.enabled,
        inputSelector = _ref$autocomplete.inputSelector,
        indexName = _ref.indexName,
        indexPrefix = _ref.indexPrefix,
        subdomain = _ref.subdomain;

    _classCallCheck(this, Autocomplete);

    if (!enabled) return;

    this._temporaryHiding(inputSelector);

    this.client = (0, _algoliasearch2.default)(applicationId, apiKey);
    this.client.addAlgoliaAgent('Zendesk Integration (__VERSION__)');
    this.indexName = indexName || '' + indexPrefix + subdomain + '_articles';
    this.index = this.client.initIndex(this.indexName);
    this.trackClick = (0, _clickAnalytics.createClickTracker)(this, this.indexName);
  }

  _createClass(Autocomplete, [{
    key: 'render',
    value: function render(_ref2) {
      var _this = this;

      var analytics = _ref2.analytics,
          _ref2$autocomplete = _ref2.autocomplete,
          enabled = _ref2$autocomplete.enabled,
          hitsPerPage = _ref2$autocomplete.hitsPerPage,
          inputSelector = _ref2$autocomplete.inputSelector,
          baseUrl = _ref2.baseUrl,
          color = _ref2.color,
          clickAnalytics = _ref2.clickAnalytics,
          debug = _ref2.debug,
          locale = _ref2.locale,
          highlightColor = _ref2.highlightColor,
          poweredBy = _ref2.poweredBy,
          subdomain = _ref2.subdomain,
          templates = _ref2.templates,
          translations = _ref2.translations;

      if (!enabled) return null;

      this.$inputs = document.querySelectorAll(inputSelector);
      this.$inputs = Array.prototype.slice.call(this.$inputs, 0); // Transform to array
      this._disableZendeskAutocomplete();

      (0, _addCSS2.default)(templates.autocomplete.css({ color: color, highlightColor: highlightColor }));
      this.autocompletes = [];

      var _loop = function _loop(i) {
        var $input = _this.$inputs[i];

        // Get the width of the dropdown
        var dropdownMenuWidth = $input.getBoundingClientRect().width;

        var sizeModifier = _this._sizeModifier(dropdownMenuWidth);
        var nbSnippetWords = _this._nbSnippetWords(dropdownMenuWidth);
        var params = {
          analytics: analytics,
          hitsPerPage: hitsPerPage,
          facetFilters: '["locale.locale:' + locale + '"]',
          highlightPreTag: '<span class="aa-article-hit--highlight">',
          highlightPostTag: '</span>',
          attributesToSnippet: ['body_safe:' + nbSnippetWords],
          snippetEllipsisText: '...'
        };

        $input.setAttribute('placeholder', translations.placeholder);
        var aa = (0, _autocomplete2.default)($input, {
          hint: false,
          debug: process.env.NODE_ENV === 'development' || debug,
          templates: _this._templates({
            poweredBy: poweredBy,
            subdomain: subdomain,
            templates: templates,
            translations: translations
          }),
          appendTo: 'body'
        }, [{
          source: _this._source(params, locale, clickAnalytics),
          name: 'articles',
          templates: {
            suggestion: _this._renderSuggestion(templates, sizeModifier)
          }
        }]);
        aa.on('autocomplete:selected', _this._onSelected(baseUrl, locale, clickAnalytics));
        aa.on('autocomplete:redrawn', function () {
          aa.autocomplete.getWrapper().style.zIndex = 10000;
        });
        aa.typeahead = (0, _zepto2.default)($input).data('aaAutocomplete');
        _this.autocompletes.push(aa);
      };

      for (var i = 0; i < this.$inputs.length; ++i) {
        _loop(i);
      }

      this._temporaryHidingCancel();
    }
  }, {
    key: 'enableDebugMode',
    value: function enableDebugMode() {
      this.autocompletes.forEach(function (aa) {
        aa.typeahead.debug = true;
      });
    }

    // Protected

  }, {
    key: '_sizeModifier',
    value: function _sizeModifier(inputWidth) {
      if (inputWidth < XS_WIDTH) return 'xs';
      if (inputWidth < SM_WIDTH) return 'sm';
      return null;
    }
  }, {
    key: '_nbSnippetWords',
    value: function _nbSnippetWords(inputWidth) {
      if (inputWidth < XS_WIDTH) return 0;
      if (inputWidth < SM_WIDTH) return 3 + Math.floor(inputWidth / 45);
      return Math.floor(inputWidth / 35);
    }
  }, {
    key: '_source',
    value: function _source(params, locale, clickAnalytics) {
      var _this2 = this;

      return function (query, callback) {
        _this2.index.search(_extends({}, params, {
          clickAnalytics: clickAnalytics,
          query: query,
          optionalWords: (0, _stopwords2.default)(query, locale)
        })).then(function (content) {
          var hitsWithPosition = _this2._addPositionToHits(content.hits, content.queryID, clickAnalytics);
          var reorderedHits = _this2._reorderedHits(hitsWithPosition);
          callback(reorderedHits);
        });
      };
    }
  }, {
    key: '_reorderedHits',
    value: function _reorderedHits(hits) {
      var groupedHits = new Map();
      hits.forEach(function (hit) {
        var category = hit.category.title;
        var section = hit.section.title;

        if (!groupedHits.has(category)) {
          hit.isCategoryHeader = true;
          groupedHits.set(category, new Map());
        }
        if (!groupedHits.get(category).has(section)) {
          hit.isSectionHeader = true;
          groupedHits.get(category).set(section, []);
        }
        groupedHits.get(category).get(section).push(hit);
      });

      var flattenedHits = [];
      groupedHits.forEach(function (sectionsValues) {
        sectionsValues.forEach(function (sectionHits) {
          sectionHits.forEach(function (sectionHit) {
            flattenedHits.push(sectionHit);
          });
        });
      });

      return flattenedHits;
    }
  }, {
    key: '_templates',
    value: function _templates(_ref3) {
      var poweredBy = _ref3.poweredBy,
          subdomain = _ref3.subdomain,
          templates = _ref3.templates,
          translations = _ref3.translations;

      var res = {};
      if (poweredBy === true) {
        res.header = templates.autocomplete.poweredBy({
          content: translations.search_by_algolia(templates.autocomplete.algolia(subdomain))
        });
      }
      return res;
    }
  }, {
    key: '_renderSuggestion',
    value: function _renderSuggestion(templates, sizeModifier) {
      return function (hit) {
        hit.sizeModifier = sizeModifier;
        return templates.autocomplete.article(hit);
      };
    }
  }, {
    key: '_onSelected',
    value: function _onSelected(baseUrl, locale, clickAnalytics) {
      var _this3 = this;

      return function (event, suggestion, dataset) {
        if (clickAnalytics) {
          var _position = suggestion._position,
              _queryID = suggestion._queryID;

          _this3.trackClick(suggestion, _position, _queryID);
        }
        location.href = '' + baseUrl + locale + '/' + dataset + '/' + suggestion.id;
      };
    }
  }, {
    key: '_temporaryHiding',
    value: function _temporaryHiding(selector) {
      this._temporaryHidingCSS = (0, _addCSS2.default)('\n      ' + selector + ' {\n        visibility: hidden !important;\n        height: 1px !important;\n      }\n    ');
    }
  }, {
    key: '_temporaryHidingCancel',
    value: function _temporaryHidingCancel() {
      (0, _removeCSS2.default)(this._temporaryHidingCSS);
      delete this._temporaryHidingCSS;
    }
  }, {
    key: '_disableZendeskAutocomplete',
    value: function _disableZendeskAutocomplete() {
      if (document.querySelector('[data-search][data-instant=true]')) {
        console.log('[Algolia][Warning] ' + 'You should remove `instant=true` from your templates to save resources');
        for (var i = 0; i < this.$inputs.length; ++i) {
          var $input = this.$inputs[i];
          var $new = $input.cloneNode();
          $input.parentNode.replaceChild($new, $input);
          this.$inputs[i] = $new;
        }
      }
    }
  }, {
    key: '_addPositionToHits',
    value: function _addPositionToHits(hits, queryID, clickAnalytics) {
      if (!clickAnalytics) return hits;
      return hits.map(function (hit, index) {
        hit._position = index + 1;
        hit._queryID = queryID;
        return hit;
      });
    }
  }]);

  return Autocomplete;
}();

exports.default = function () {
  for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
    args[_key] = arguments[_key];
  }

  return new (Function.prototype.bind.apply(Autocomplete, [null].concat(args)))();
};