'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.initInsights = initInsights;
exports.createClickTracker = createClickTracker;
exports.extendWithConversionTracking = extendWithConversionTracking;

var _jsCookie = require('js-cookie');

var _jsCookie2 = _interopRequireDefault(_jsCookie);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function initInsights(_ref) {
  var applicationId = _ref.applicationId,
      apiKey = _ref.apiKey;

  var ALGOLIA_INSIGHTS_SRC = 'https://cdn.jsdelivr.net/npm/search-insights@1';

  /* eslint-disable */
  !function (e, a, t, n, s, i, c) {
    e.AlgoliaAnalyticsObject = s, e.aa = e.aa || function () {
      (e.aa.queue = e.aa.queue || []).push(arguments);
    }, i = a.createElement(t), c = a.getElementsByTagName(t)[0], i.async = 1, i.src = ALGOLIA_INSIGHTS_SRC, c.parentNode.insertBefore(i, c);
  }(window, document, "script", 0, "aa");
  /* eslint-enable */

  window.aa('init', { appId: applicationId, apiKey: apiKey });
}

function createClickTracker(self, index) {
  return function trackClick(article, position, queryID) {
    if (!window.aa) return;
    if (self._saveLastClick) self._saveLastClick(queryID, article);
    window.aa('clickedObjectIDsAfterSearch', {
      eventName: 'article_clicked',
      index: index,
      queryID: queryID,
      objectIDs: [article.objectID],
      positions: [Number(position)]
    });
  };
}

// Extends instance with clickAnalytics specific attributes
function extendWithConversionTracking(self, _ref2) {
  var clickAnalytics = _ref2.clickAnalytics,
      indexName = _ref2.indexName,
      indexPrefix = _ref2.indexPrefix,
      subdomain = _ref2.subdomain;

  var finalIndexName = indexName || '' + indexPrefix + subdomain + '_articles';

  if (!clickAnalytics) {
    self._saveLastQueryID = function () {};
    self._saveLastClick = function () {};
    self.trackConversion = function () {};
    return;
  }

  self._saveLastClick = function (queryID, article) {
    var cookieBody = JSON.stringify({
      queryID: queryID,
      objectID: article.objectID,
      articleID: article.id
    });
    _jsCookie2.default.set('algolia-last-click', cookieBody, { expires: 1 });
  };
  self.trackConversion = function (articleID) {
    var lastClickRaw = _jsCookie2.default.get('algolia-last-click');
    if (!lastClickRaw) return;
    var lastClick = JSON.parse(lastClickRaw);

    if (!lastClick.queryID || !lastClick.objectID || !lastClick.articleID) return;

    if (articleID !== lastClick.articleID) return;

    window.aa('convertedObjectIDsAfterSearch', {
      index: finalIndexName,
      eventName: 'article_conversion',
      queryID: lastClick.queryID,
      objectIDs: [lastClick.objectID]
    });

    self._saveLastClick(lastClick.queryID, {});
  };
}