'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.default = loadTemplates;

var _compile = require('./compile');

var _compile2 = _interopRequireDefault(_compile);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var defaultTemplates = {
  autocomplete: {
    // Algolia logo
    algolia: function algolia(subdomain) {
      return '<a\n  href="https://www.algolia.com/?utm_source=zendesk&utm_medium=link&utm_campaign=autocomplete-' + subdomain + '"\n  class="aa-powered-by-link"\n>\n  Algolia\n</a>';
    },

    // Autocompletion template for an article
    article: (0, _compile2.default)('<div\n  class="\n    aa-article-hit\n    [[# isCategoryHeader ]]aa-article-hit__category-first[[/ isCategoryHeader ]]\n    [[# isSectionHeader ]]aa-article-hit__section-first[[/ isSectionHeader ]]\n    [[# sizeModifier ]]aa-article-hit__[[ sizeModifier ]][[/ sizeModifier]]\n  "\n>\n  <div class="aa-article-hit--category">\n    <span class="aa-article-hit--category--content">\n      [[ category.title ]]\n    </span>\n  </div>\n  <div class="aa-article-hit--line">\n    <div class="aa-article-hit--section">\n      [[ section.title ]]\n    </div>\n    <div class="aa-article-hit--content">\n      <div class="aa-article-hit--headline">\n        <span class="aa-article-hit--title">\n          [[& _highlightResult.title.value ]]\n        </span>\n      </div>\n      [[# _snippetResult.body_safe.value ]]\n        <div class="aa-article-hit--body">[[& _snippetResult.body_safe.value ]]</div>\n      [[/ _snippetResult.body_safe.value ]]\n    </div>\n  </div>\n</div>\n<div class="clearfix"></div>'),

    // Powered By
    poweredBy: (0, _compile2.default)('<div class="aa-powered-by">\n  [[& content ]]\n</div>'),

    // CSS to add to handle the color
    css: (0, _compile2.default)('.aa-article-hit--highlight {\n  color: [[ color ]];\n}\n\n.aa-article-hit--section {\n  color: [[ color ]];\n}\n\n.aa-article-hit--title .aa-article-hit--highlight {\n  color: [[ highlightColor ]];\n}\n\n.aa-article-hit--title .aa-article-hit--highlight::before {\n  background-color: [[ highlightColor ]];\n}')
  },

  instantsearch: {
    css: (0, _compile2.default)('.search-result-link, .ais-hierarchical-menu--link, .ais-link {\n  color: [[ color ]];\n}\n\n.search-result-link .ais-highlight {\n  color: [[ highlightColor ]];\n}\n\n.search-result-link .ais-highlight::before {\n  background-color: [[ highlightColor ]];\n}\n\n#algolia-facets-open {\n  color: [[ color ]];\n}'),

    responsiveCSS: '@media (max-width: 768px) {\n  #algolia-facets-open {\n    display: block;\n    text-align: center;\n    cursor: pointer;\n    float: right;\n    padding: 0 9px;\n  }\n\n  .ais-with-style.ais-search-box {\n    margin-left: 0;\n  }\n\n  #algolia-facets {\n    display: none;\n  }\n\n  #algolia-stats {\n    margin-left: 0;\n    width: 100%;\n  }\n\n  #algolia-hits {\n    margin-left: 0;\n    width: 100%;\n  }\n}',

    responsiveCSSFacets: '@media (max-width: 768px) {\n  body {\n    position: fixed;\n    overflow: hidden;\n  }\n\n  #algolia-facets {\n    padding: 20px 0;\n    position: fixed;\n    z-index: 10000;\n    top: 0;\n    left: 0;\n    bottom: 0;\n    width: 100%;\n    height: 100%;\n    background: white;\n    overflow-y: scroll;\n    overflow-x: hidden;\n    display: block;\n  }\n\n  #algolia-facets-close {\n    display: inline-block;\n    position: absolute;\n    top: 0;\n    right: 0;\n    font-size: 1.5em;\n    padding: 20px 20px;\n    cursor: pointer;\n  }\n}',

    layout: (0, _compile2.default)('<div>\n  <input type="text" id="algolia-query"/>\n  <div id="algolia-stats-line">\n    <div id="algolia-facets-open">\n      [[ translations.filter ]]\n    </div>\n    <div id="algolia-stats"></div>\n  </div>\n  <div id="algolia-facets">\n    <div id="algolia-facets-close">\n      <div id="algolia-facets-close-button">\n        \u2716\n      </div>\n    </div>\n    <div id="algolia-categories"></div>\n    <div id="algolia-labels"></div>\n  </div>\n  <div id="algolia-hits"></div>\n  <div class="clearfix"></div>\n  <div id="algolia-pagination"></div>\n</div>'),

    hierarchicalItem: (0, _compile2.default)('<a class="[[cssClasses.link]]" href="[[url]]" title="[[name]]">\n  [[name]]\n  <span class="[[cssClasses.count]]">\n    [[#helpers.formatNumber]]\n      [[count]]\n    [[/helpers.formatNumber]]\n  </span>\n</a>'),

    // Instant search result template
    hit: (0, _compile2.default)('<div\n  class="search-result"\n  data-algolia-position="[[ position ]]"\n  data-algolia-queryid="[[ queryID ]]"\n  data-algolia-articleid="[[ id ]]"\n  data-algolia-objectid="[[ objectID ]]"\n>\n  <div class="search-result-meta">\n    <time data-datetime="relative" datetime="[[# useEditedAt ]][[ edited_at_iso ]][[/ useEditedAt]][[^ useEditedAt ]][[ created_at_iso ]][[/ useEditedAt  ]]"></time>\n  </div>\n  [[# showHitsFullPath ]]<div class="search-result-path">[[ section.full_path ]]</div>[[/ showHitsFullPath ]]\n  <div class="search-result-link-wrapper">\n    <a class="search-result-link" href="[[ baseUrl ]][[ locale.locale ]]/articles/[[ id ]]">\n      [[& _highlightResult.title.value ]]\n    </a>\n    [[# vote_sum ]]<span class="search-result-votes">[[ vote_sum ]]</span>[[/ vote_sum ]]\n  </div>\n  <div class="search-result-body">\n    [[& _snippetResult.body_safe.value ]]\n  </div>\n</div>'),

    noResult: function noResult(_ref) {
      var query = _ref.query,
          translations = _ref.translations;
      return '<div id="no-results-message">\n  <p>' + translations.no_result_for(query) + '</p>\n  <p>' + translations.no_result_actions() + '</p>\n</div>';
    },

    poweredBy: function poweredBy(_ref2) {
      var subdomain = _ref2.subdomain,
          translations = _ref2.translations;
      return (0, _compile2.default)('<div class="[[ cssClasses.root ]]">\n  ' + translations.search_by_algolia('<a class="[[ cssClasses.link ]]" href="https://www.algolia.com/?utm_source=zendesk&utm_medium=link&utm_campaign=instantsearch-' + subdomain + '" target="_blank">Algolia</a>') + '\n</div>');
    }
  }
};

function loadTemplates(options) {
  options.templates = {
    autocomplete: _extends({}, defaultTemplates.autocomplete, options.templates.autocomplete),
    instantsearch: _extends({}, defaultTemplates.instantsearch, options.templates.instantsearch)
  };
}