'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.loadTranslations = loadTranslations;

var _escapeHTML = require('./escapeHTML');

var _escapeHTML2 = _interopRequireDefault(_escapeHTML);

var _getCurrentLocale = require('./getCurrentLocale');

var _getCurrentLocale2 = _interopRequireDefault(_getCurrentLocale);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint object-shorthand: 0 */

var LOCALES_ASSOCIATIONS = {
  'ar-eg': 'ar',
  'de-at': 'de',
  'de-ch': 'de',
  'en-au': 'en',
  'en-ca': 'en',
  'en-gb': 'en',
  'en-us': 'en',
  'en-ie': 'en',
  'es-es': 'es',
  'es-419': 'es',
  'fr-be': 'fr',
  'fr-ca': 'fr',
  'fr-ch': 'fr',
  'fr-fr': 'fr',
  'nl-be': 'nl',
  'pt-br': 'pt'
};

var TRANSLATIONS = {
  categories: {
    ar: 'الفئات',
    bg: 'Категории',
    cs: 'Kategorie',
    da: 'Kategorier',
    de: 'Kategorien',
    en: 'Categories',
    el: 'Ελληνικά',
    es: 'Categorías',
    fi: 'Kategoriat',
    fr: 'Catégories',
    hu: 'Kategóriák',
    id: 'Kategori',
    it: 'Categorie',
    ja: 'カテゴリー',
    ko: '카테고리',
    nl: 'Categorieën',
    no: 'Kategorier',
    pl: 'Kategorie',
    pt: 'Categorias',
    ro: 'Categorii',
    ru: 'Категории',
    sk: 'Kategorier',
    sv: 'Kategorier',
    th: 'หมวดหมู่',
    tr: 'Kategoriler',
    uk: 'Категорії',
    vi: 'Loại',
    'zh-cn': '类别',
    'zh-tw': '類別'
  },
  change_query: {
    ar: 'قم بتغيير الاستفسار',
    bg: 'променете вашата заявка',
    cs: 'Změňte svůj dotaz',
    da: 'Ændr din forespørgsel',
    de: 'Ihre Abfrage ändern',
    el: 'Αλλάξτε το ερώτημά σας',
    en: 'Change your query',
    es: 'Cambiar su consulta',
    fi: 'Vaihda hakusanaasi',
    fr: 'Changer votre requête',
    hu: 'Módosítsa keresését',
    id: 'Ubah pencarian Anda',
    it: 'Modifica la tua query',
    ja: '検索内容を変更',
    ko: '검색어를 변경하',
    nl: 'Wijzig je zoekopdracht',
    no: 'Endre søket ditt',
    pl: 'Zmień zapytanie',
    pt: 'Modifique a sua pesquisa',
    'pt-br': 'Altere sua consulta',
    ro: 'Modificați-vă întrebările',
    ru: 'Изменить запрос',
    sk: 'Zmeňte dotaz',
    sv: 'Ändra din fråga',
    th: 'เปลี่ยนการสืบค้นของคุณ',
    tr: 'Sorgunuzu değiştirin',
    uk: 'змініть свій запит',
    vi: 'Thay đổi truy vấn của bạn',
    'zh-cn': '更改您的查询',
    'zh-tw': '變更問題'
  },
  clear_filters: {
    ar: 'قم بمسح المرشحات',
    bg: 'почистете вашите филтри',
    cs: 'zrušte své filtry',
    da: 'ryd dine filtre',
    de: 'Ihre Filter leeren',
    el: 'καθαρίστε τα φίλτρα σας',
    en: 'clear your filters',
    es: 'borrar sus filtros',
    fi: 'nollaa hakuehdot',
    fr: 'enlever vos filtres',
    hu: 'törölje a szűrőket',
    id: 'hapus filter Anda',
    it: 'elimina i filtri',
    ja: 'フィルターをリセットしてください。',
    ko: '필터를 제거하세요',
    nl: 'wis je filters',
    no: 'tøm filtrene dine',
    pl: 'zresetuj filtry',
    pt: 'limpe os seus filtros',
    'pt-br': 'retirar filtros',
    ro: 'ștergeți-vă filtrele',
    ru: 'сбросить фильтры',
    sk: 'vymažte filtre',
    sv: 'rensa filter',
    th: 'ล้างตัวกรอง',
    tr: 'filtrelerinizi temizleyin',
    uk: 'очистіть свої фільтри',
    vi: 'xóa bộ lọc của bạn',
    'zh-cn': '清除过滤条件',
    'zh-tw': '清理篩選'
  },
  format_number: {
    ar: function ar(n) {
      return n.toString().replace(/\B(?=(\d{3})+(?!\d))/g, '');
    },
    bg: function bg(n) {
      return n.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ' ');
    },
    cs: function cs(n) {
      return n.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ' ');
    }, // Non-breaking space
    da: function da(n) {
      return n.toString().replace(/\B(?=(\d{3})+(?!\d))/g, '.');
    },
    de: function de(n) {
      return n.toString().replace(/\B(?=(\d{3})+(?!\d))/g, '.');
    },
    el: function el(n) {
      return n.toString().replace(/\B(?=(\d{3})+(?!\d))/g, '.');
    },
    en: function en(n) {
      return n.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ',');
    },
    es: function es(n) {
      return n.toString().replace(/\B(?=(\d{3})+(?!\d))/g, '.');
    },
    fr: function fr(n) {
      return n.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ' ');
    },
    hu: function hu(n) {
      return n.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ' ');
    },
    id: function id(n) {
      return n.toString().replace(/\B(?=(\d{3})+(?!\d))/g, '.');
    },
    it: function it(n) {
      return n.toString().replace(/\B(?=(\d{3})+(?!\d))/g, '.');
    },
    nl: function nl(n) {
      return n.toString().replace(/\B(?=(\d{3})+(?!\d))/g, '.');
    },
    no: function no(n) {
      return n.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ' ');
    }, // Non-breaking space
    pl: function pl(n) {
      return n.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ' ');
    },
    pt: function pt(n) {
      return n.toString().replace(/\B(?=(\d{3})+(?!\d))/g, '.');
    },
    ro: function ro(n) {
      return n.toString().replace(/\B(?=(\d{3})+(?!\d))/g, '.');
    },
    ru: function ru(n) {
      return n.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ' ');
    },
    sk: function sk(n) {
      return n.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ' ');
    }, // Non-breaking space
    sv: function sv(n) {
      return n.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ' ');
    },
    tr: function tr(n) {
      return n.toString().replace(/\B(?=(\d{3})+(?!\d))/g, '.');
    },
    uk: function uk(n) {
      return n.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ' ');
    }
  },
  filter: {
    ar: 'نتائج الترشيح',
    bg: 'Филтриране на резултати',
    cs: 'Filtrovat výsledky',
    da: 'Filterresultater',
    de: 'Ergebnisse filtern',
    el: 'Αποτελέσματα φίλτρου',
    en: 'Filter results',
    es: 'Filtrar los resultados',
    fi: 'Muokkaa hakuehtoja',
    fr: 'Filtrer les résultats',
    hu: 'Eredmények szűrése',
    id: 'Filter hasil',
    it: 'Filtrare risultati',
    ja: 'フィルターされた結果',
    ko: '필터 결과',
    nl: 'Filter resultaten',
    no: 'Filtrer resultater',
    pl: 'Filtruj wyniki',
    pt: 'Filtrar resultados',
    ro: 'Filtrează rezultate',
    ru: 'фильтр',
    sk: 'Výsledky filtrovania',
    sv: 'Filtrera resultat',
    th: 'ผลลัพธ์จากตัวกรอง',
    tr: 'Sonuçları filtrele',
    uk: 'Фільтрувати результати',
    vi: 'Lọc kết quả',
    'zh-cn': '筛选结果',
    'zh-tw': '篩選結果'
  },
  nb_results: {
    ar: function ar(nb) {
      return nb > 1 ? this.format_number(nb) + ' \u0646\u062A\u064A\u062C\u0629' : 'نتيجة واحدة';
    },
    bg: function bg(nb) {
      return this.format_number(nb) + ' \u0440\u0435\u0437\u0443\u043B\u0442\u0430\u0442' + (nb > 1 ? 'а' : '');
    },
    cs: function cs(nb) {
      var suffix = 'ek';
      if (nb > 1) suffix = 'ky';
      if (nb > 4) suffix = 'ků';
      return this.format_number(nb) + ' v\xFDsled' + suffix;
    },
    da: function da(nb) {
      return this.format_number(nb) + ' resultat' + (nb > 1 ? 'er' : '');
    },
    de: function de(nb) {
      return this.format_number(nb) + ' Ergebnis' + (nb > 1 ? 'se' : '');
    },
    el: function el(nb) {
      return this.format_number(nb) + ' \u03B1\u03C0\u03BF\u03C4\u03AD\u03BB\u03B5\u03C3\u03BC\u03B1' + (nb > 1 ? 'τα' : '');
    },
    en: function en(nb) {
      return this.format_number(nb) + ' result' + (nb > 1 ? 's' : '');
    },
    es: function es(nb) {
      return this.format_number(nb) + ' resultado' + (nb > 1 ? 's' : '');
    },
    fi: function fi(nb) {
      return this.format_number(nb) + ' tulos' + (nb > 1 ? 'ta' : '');
    },
    fr: function fr(nb) {
      return this.format_number(nb) + ' r\xE9sultat' + (nb > 1 ? 's' : '');
    },
    hu: function hu(nb) {
      return this.format_number(nb) + ' tal\xE1lat';
    },
    id: function id(nb) {
      return this.format_number(nb) + ' hasil';
    },
    it: function it(nb) {
      return this.format_number(nb) + ' risultat' + (nb > 1 ? 'i' : 'o');
    },
    ja: function ja(nb) {
      return this.format_number(nb) + '\u500B\u306E\u7D50\u679C';
    },
    ko: function ko(nb) {
      return this.format_number(nb) + '\uAC74\uC758';
    },
    nl: function nl(nb) {
      return this.format_number(nb) + ' resulta' + (nb > 1 ? 'ten' : 'at');
    },
    no: function no(nb) {
      return this.format_number(nb) + ' resultat' + (nb > 1 ? 'er' : '');
    },
    pl: function pl(nb) {
      return this.format_number(nb) + ' wynik' + (nb > 1 ? 'ów' : '');
    },
    pt: function pt(nb) {
      return this.format_number(nb) + ' resultado' + (nb > 1 ? 's' : '');
    },
    ro: function ro(nb) {
      return this.format_number(nb) + ' rezultat' + (nb > 1 ? 'e' : '');
    },
    ru: function ru(nb) {
      var suffix = '';
      if (nb % 10 === 1 && nb % 100 !== 11) suffix = '';else if (nb % 10 >= 2 && nb % 10 <= 4 && (nb % 100 < 10 || nb % 100 >= 20)) suffix = 'а';else suffix = 'ов';
      return this.format_number(nb) + ' \u0440\u0435\u0437\u0443\u043B\u044C\u0442\u0430\u0442' + suffix;
    },
    sk: function sk(nb) {
      var suffix = 'ok';
      if (nb > 1) suffix = 'ky';
      if (nb > 4) suffix = 'kov';
      return this.format_number(nb) + ' v\xFDsled' + suffix;
    },
    sv: function sv(nb) {
      return this.format_number(nb) + ' tr\xE4ff' + (nb > 1 ? 'ar' : '');
    },
    th: function th(nb) {
      return this.format_number(nb) + ' \u0E1C\u0E25\u0E25\u0E31\u0E1E\u0E18\u0E4C\u0E43\u0E19';
    },
    tr: function tr(nb) {
      return this.format_number(nb) + ' sonu\xE7';
    },
    uk: function uk(nb) {
      var suffix = '';
      if (nb % 10 === 1 && nb % 100 !== 11) suffix = '';else if (nb % 10 >= 2 && nb % 10 <= 4 && (nb % 100 < 10 || nb % 100 >= 20)) suffix = 'и';else suffix = '';
      return this.format_number(nb) + ' \u0440\u0435\u0437\u0443\u043B\u044C\u0442\u0430\u0442' + suffix;
    },
    vi: function vi(nb) {
      return this.format_number(nb) + ' k\u1EBFt qu\u1EA3 \u0111\u01B0\u1EE3c t\xECm';
    },
    'zh-cn': function zhCn(nb) {
      return this.format_number(nb) + '\u4E2A\u7ED3\u679C';
    },
    'zh-tw': function zhTw(nb) {
      return this.format_number(nb) + ' \u9805\u7D50\u679C';
    }
  },
  no_result_for: {
    ar: function ar(query) {
      return '\u0644\u0645 \u064A\u062A\u0645 \u0627\u0644\u0639\u062B\u0648\u0631 \u0639\u0644\u0649 \u0646\u062A\u0627\u0626\u062C \u0644\u0635\u0627\u0644\u062D ' + this.quoted(query);
    },
    bg: function bg(query) {
      return '\u041D\u044F\u043C\u0430 \u043D\u0430\u043C\u0435\u0440\u0435\u043D \u0440\u0435\u0437\u0443\u043B\u0442\u0430\u0442 \u0437\u0430 ' + this.quoted(query);
    },
    cs: function cs(query) {
      return 'Pro dotaz ' + this.quoted(query) + ' nebyly nalezeny \u017E\xE1dn\xE9 v\xFDsledky';
    },
    da: function da(query) {
      return 'Ingen resultater fundet for ' + this.quoted(query);
    },
    de: function de(query) {
      return 'Keine Ergebnisse f\xFCr ' + this.quoted(query) + ' gefunden';
    },
    el: function el(query) {
      return '\u0394\u03B5\u03BD \u03B2\u03C1\u03AD\u03B8\u03B7\u03BA\u03B5 \u03B1\u03C0\u03BF\u03C4\u03AD\u03BB\u03B5\u03C3\u03BC\u03B1 \u03B3\u03B9\u03B1 ' + this.quoted(query);
    },
    en: function en(query) {
      return 'No result found for ' + this.quoted(query);
    },
    es: function es(query) {
      return 'No se han encontrado resultados para ' + this.quoted(query);
    },
    fi: function fi(query) {
      return 'Tuloksia hakusanalla ' + this.quoted(query) + ' ei l\xF6ytynyt';
    },
    fr: function fr(query) {
      return 'Aucun r\xE9sultat pour ' + this.quoted(query);
    },
    hu: function hu(query) {
      return 'Nicns tal\xE1lat erre: ' + this.quoted(query);
    },
    id: function id(query) {
      return 'Tak ditemukan hasil untuk ' + this.quoted(query);
    },
    it: function it(query) {
      return 'Nessun risultato trovato per ' + this.quoted(query);
    },
    ja: function ja(query) {
      return this.quoted(query) + '\u306E\u7D50\u679C\u304C\u898B\u3064\u304B\u308A\u307E\u305B\u3093\u3067\u3057\u305F\u3002';
    },
    ko: function ko(query) {
      return this.quoted(query) + '\uC5D0 \uB300\uD55C \uAC80\uC0C9 \uACB0\uACFC\uAC00 \uC5C6\uC2B5\uB2C8\uB2E4';
    },
    nl: function nl(query) {
      return 'Geen resultaten voor ' + this.quoted(query);
    },
    no: function no(query) {
      return 'Ingen resultater funnet for ' + this.quoted(query);
    },
    pl: function pl(query) {
      return 'Nie znaleziono wynik\xF3w dla ' + this.quoted(query);
    },
    pt: function pt(query) {
      return 'N\xE3o foram encontrados resultados para ' + this.quoted(query);
    },
    'pt-br': function ptBr(query) {
      return 'Nenhum resultado encontrado para ' + this.quoted(query);
    },
    ro: function ro(query) {
      return 'Niciun rezultat pentru ' + this.quoted(query);
    },
    ru: function ru(query) {
      return '\u041F\u043E \u0437\u0430\u043F\u0440\u043E\u0441\u0443 ' + this.quoted(query) + ' \u043D\u0438\u0447\u0435\u0433\u043E \u043D\u0435 \u043D\u0430\u0439\u0434\u0435\u043D\u043E';
    },
    sk: function sk(query) {
      return 'Pre ' + this.quoted(query) + ' nebol n\xE1jden\xFD \u017Eiadny v\xFDsledok';
    },
    sv: function sv(query) {
      return 'Inget resultat hittades f\xF6r ' + this.quoted(query);
    },
    th: function th(query) {
      return '\u0E44\u0E21\u0E48\u0E1E\u0E1A\u0E1C\u0E25\u0E25\u0E31\u0E1E\u0E18\u0E4C\u0E2A\u0E33\u0E2B\u0E23\u0E31\u0E1A ' + this.quoted(query);
    },
    tr: function tr(query) {
      return this.quoted(query) + ' i\xE7in sonu\xE7 bulunamad\u0131';
    },
    uk: function uk(query) {
      return '\u041D\u0435 \u0437\u043D\u0430\u0439\u0434\u0435\u043D\u043E \u0440\u0435\u0437\u0443\u043B\u044C\u0442\u0430\u0442\u0456\u0432 \u0434\u043B\u044F ' + this.quoted(query);
    },
    vi: function vi(query) {
      return 'Kh\xF4ng c\xF3 k\u1EBFt qu\u1EA3 \u0111\u01B0\u1EE3c t\xECm th\u1EA5y cho ' + this.quoted(query);
    },
    'zh-cn': function zhCn(query) {
      return '\u672A\u627E\u5230 ' + this.quoted(query) + ' \u7684\u7ED3\u679C';
    },
    'zh-tw': function zhTw(query) {
      return '\u67E5\u7121 ' + this.quoted(query) + ' \u76F8\u95DC\u7D50\u679C';
    }
  },
  no_result_actions: {
    ar: function ar() {
      return this.change_query + ' \u0623\u0648 ' + this.clear_filters;
    },
    bg: function bg() {
      return this.change_query + ' \u0438\u043B\u0438 ' + this.clear_filters;
    },
    cs: function cs() {
      return this.change_query + ' nebo ' + this.clear_filters;
    },
    da: function da() {
      return this.change_query + ' eller ' + this.clear_filters;
    },
    de: function de() {
      return this.change_query + ' oder ' + this.clear_filters;
    },
    el: function el() {
      return this.change_query + ' \u03AE ' + this.clear_filters;
    },
    en: function en() {
      return this.change_query + ' or ' + this.clear_filters;
    },
    es: function es() {
      return this.change_query + ' o ' + this.clear_filters;
    },
    fi: function fi() {
      return this.change_query + ' tai ' + this.clear_filters;
    },
    fr: function fr() {
      return this.change_query + ' ou ' + this.clear_filters;
    },
    hu: function hu() {
      return this.change_query + ' vagy ' + this.clear_filters;
    },
    id: function id() {
      return this.change_query + ' atau ' + this.clear_filters;
    },
    it: function it() {
      return this.change_query + ' o ' + this.clear_filters;
    },
    ja: function ja() {
      return this.change_query + '\u3059\u308B\u304B\u3001' + this.clear_filters;
    },
    ko: function ko() {
      return this.change_query + ' \uAC70\uB098 ' + this.clear_filters;
    },
    nl: function nl() {
      return this.change_query + ' of ' + this.clear_filters;
    },
    no: function no() {
      return this.change_query + ' eller ' + this.clear_filters;
    },
    pl: function pl() {
      return this.change_query + ' lub ' + this.clear_filters;
    },
    pt: function pt() {
      return this.change_query + ' ou ' + this.clear_filters;
    },
    ro: function ro() {
      return this.change_query + ' sau ' + this.clear_filters;
    },
    ru: function ru() {
      return this.change_query + ' \u0438\u043B\u0438 ' + this.clear_filters;
    },
    sk: function sk() {
      return this.change_query + ' alebo ' + this.clear_filters;
    },
    sv: function sv() {
      return this.change_query + ' eller ' + this.clear_filters;
    },
    th: function th() {
      return this.change_query + ' \u0E2B\u0E23\u0E37\u0E2D ' + this.clear_filters;
    },
    tr: function tr() {
      return this.change_query + ' ya da ' + this.clear_filters;
    },
    uk: function uk() {
      return this.change_query + ' \u0430\u0431\u043E ' + this.clear_filters;
    },
    vi: function vi() {
      return this.change_query + ' ho\u1EB7c ' + this.clear_filters;
    },
    'zh-cn': function zhCn() {
      return this.change_query + '\u6216' + this.clear_filters;
    },
    'zh-tw': function zhTw() {
      return this.change_query + '\u6216' + this.clear_filters;
    }
  },
  placeholder: {
    ar: 'البحث في مقالاتنا',
    bg: 'Търсене в нашите статии',
    cs: 'Hledat v našich článcích',
    da: 'Søg i vores artikler',
    de: 'In unseren Artikeln suchen',
    el: 'Κάντε αναζήτηση στα άρθρα μας',
    en: 'Search our articles',
    es: 'Buscar en nuestros artículos',
    fi: 'Etsi artikkeleista',
    fr: 'Recherchez dans nos articles',
    hu: 'Keresés a cikkeink között',
    id: 'Cari di artikel kami',
    it: 'Cerca nei nostri articoli',
    ja: '私たちの記事を検索します。',
    ko: '기사에서 검색',
    nl: 'Zoeken in onze artikelen',
    no: 'Søk i våre artikler',
    pl: 'Szukaj w naszych artykułach',
    pt: 'Pesquisar nos nossos artigos',
    'pt-br': 'Pesquise em nossos artigos',
    ro: 'Căutați în articolele noastre',
    ru: 'Найти в наших статьях',
    sk: 'Vyhľadávať v našich článkoch',
    sv: 'Sök bland våra artiklar',
    th: 'ค้นหาในบทความของเรา',
    tr: 'Yazılarımızda ara',
    uk: 'Пошук у наших статтях',
    vi: 'Tìm kiếm trong các bài viết của chúng tôi',
    'zh-cn': '在我们的文章中搜索',
    'zh-tw': '在文章中搜尋'
  },
  quoted: {
    cs: function cs(text) {
      return '\u201E' + (0, _escapeHTML2.default)(text) + '\u201C';
    },
    el: function el(text) {
      return '\xAB' + (0, _escapeHTML2.default)(text) + '\xBB';
    },
    en: function en(text) {
      return '"' + (0, _escapeHTML2.default)(text) + '"';
    },
    fi: function fi(text) {
      return '\u201D' + (0, _escapeHTML2.default)(text) + '\u201D';
    },
    'zh-cn': function zhCn(text) {
      return '\u201C' + (0, _escapeHTML2.default)(text) + '\u201D';
    },
    'zh-tw': function zhTw(text) {
      return '\u300C' + (0, _escapeHTML2.default)(text) + '\u300D';
    }
  },
  stats: {
    ar: function ar(nbHits, processing) {
      return '\u062A\u0645 \u0627\u0644\u0639\u062B\u0648\u0631 \u0639\u0644\u0649 ' + this.nb_results(nbHits) + ' \u0641\u064A ' + processing + ' \u0645\u0644\u0644\u064A \u062B\u0627\u0646\u064A\u0629';
    },
    bg: function bg(nbHits, processing) {
      return this.nb_results(nbHits) + ' \u043D\u0430\u043C\u0435\u0440\u0435\u043D' + (nbHits > 1 ? 'и' : '') + ' \u0437\u0430 ' + processing + ' \u043C\u0441';
    },
    cs: function cs(nbHits, processing) {
      var suffix = '';
      if (nbHits > 1) suffix = 'y';
      if (nbHits > 4) suffix = 'o';
      return this.nb_results(nbHits) + ' nalezen' + suffix + ' za ' + processing + ' ms';
    },
    da: function da(nbHits, processing) {
      return this.nb_results(nbHits) + ' fundet p\xE5 ' + processing + ' ms';
    },
    de: function de(nbHits, processing) {
      return this.nb_results(nbHits) + ' gefunden in ' + processing + ' ms';
    },
    el: function el(nbHits, processing) {
      return '\u0392\u03C1\u03AD\u03B8\u03B7\u03BA' + (nbHits > 1 ? 'αν' : 'ε') + ' ' + this.nb_results(nbHits) + ' \u03C3\u03B5 ' + processing + ' ms';
    },
    en: function en(nbHits, processing) {
      return this.nb_results(nbHits) + ' found in ' + processing + ' ms';
    },
    es: function es(nbHits, processing) {
      return this.nb_results(nbHits) + ' encontrado' + (nbHits > 1 ? 's' : '') + ' en ' + processing + ' ms';
    },
    fi: function fi(nbHits, processing) {
      return this.nb_results(nbHits) + ' l\xF6ydetty ajassa ' + processing + ' ms';
    },
    fr: function fr(nbHits, processing) {
      return this.nb_results(nbHits) + ' trouv\xE9' + (nbHits > 1 ? 's' : '') + ' en ' + processing + ' ms';
    },
    hu: function hu(nbHits, processing) {
      return this.nb_results(nbHits) + ' ' + processing + ' ms alatt';
    },
    id: function id(nbHits, processing) {
      return this.nb_results(nbHits) + ' hasil ditemukan dalam ' + processing + ' md';
    },
    it: function it(nbHits, processing) {
      return this.nb_results(nbHits) + ' trovat' + (nbHits > 1 ? 'i' : 'o') + ' in ' + processing + ' ms';
    },
    ja: function ja(nbHits, processing) {
      return this.nb_results(nbHits) + '\u304C' + processing + '\u30DF\u30EA\u79D2\u3067\u898B\u3064\u304B\u308A\u307E\u3057\u305F\u3002';
    },
    ko: function ko(nbHits, processing) {
      return processing + ' \uBC00\uB9AC\uCD08\uC5D0 ' + this.nb_results(nbHits) + ' \uACB0\uACFC\uAC00 \uAC80\uC0C9\uB428';
    },
    nl: function nl(nbHits, processing) {
      return this.nb_results(nbHits) + ' in ' + processing + ' ms';
    },
    no: function no(nbHits, processing) {
      return this.nb_results(nbHits) + ' funnet etter ' + processing + ' ms';
    },
    pt: function pt(nbHits, processing) {
      return this.nb_results(nbHits) + ' encontrado' + (nbHits > 1 ? 's' : '') + ' em ' + processing + ' ms';
    },
    pl: function pl(nbHits, processing) {
      return 'Znaleziono ' + this.nb_results(nbHits) + ' w czasie ' + processing + ' ms';
    },
    ro: function ro(nbHits, processing) {
      return this.nb_results(nbHits) + ' g\u0103sit' + (nbHits > 1 ? 'e' : '') + ' \xEEn ' + processing + ' ms';
    },
    ru: function ru(nbHits, processing) {
      return this.nb_results(nbHits) + ' \u0437\u043D\u0430\u0439\u0434\u0435\u043D\u043E \u0437\u0430 ' + processing + ' \u043C\u0441';
    },
    sk: function sk(nbHits, processing) {
      var suffix = 'ý';
      if (nbHits > 1) suffix = 'é';
      if (nbHits > 4) suffix = 'ých';
      return this.nb_results(nbHits) + ' n\xE1jden\xFD' + suffix + ' za ' + processing + ' ms';
    },
    sv: function sv(nbHits, processing) {
      return this.nb_results(nbHits) + ' ' + (nbHits > 1 ? 'hittades' : '') + ' p\xE5 ' + processing + ' ms';
    },
    th: function th(nbHits, processing) {
      return '\u0E1E\u0E1A ' + this.nb_results(nbHits) + ' ' + processing + ' \u0E21\u0E34\u0E25\u0E25\u0E34\u0E27\u0E34\u0E19\u0E32\u0E17\u0E35';
    },
    tr: function tr(nbHits, processing) {
      return processing + ' ms i\xE7erisinde ' + this.nb_results(nbHits) + ' sonu\xE7 bulundu';
    },
    uk: function uk(nbHits, processing) {
      return this.nb_results(nbHits) + ' \u0437\u043D\u0430\u0439\u0434\u0435\u043D\u043E \u0437\u0430 ' + processing + ' \u043C\u0441';
    },
    vi: function vi(nbHits, processing) {
      return this.nb_results(nbHits) + ' th\u1EA5y trong ' + processing + ' mili gi\xE2y';
    },
    'zh-cn': function zhCn(nbHits, processing) {
      return '\u5728 ' + processing + ' ms \u5185\u627E\u5230 ' + this.nb_results(nbHits);
    },
    'zh-tw': function zhTw(nbHits, processing) {
      return processing + ' \u6BEB\u79D2\u5167\u641C\u5C0B\u5230 ' + this.nb_results(nbHits);
    }
  },
  search_by_algolia: {
    ar: function ar(algolia) {
      return '\u0627\u0644\u0628\u062D\u062B \u0628\u0648\u0627\u0633\u0637\u0629 ' + algolia;
    },
    bg: function bg(algolia) {
      return '\u0422\u044A\u0440\u0441\u0435\u043D\u0435 \u043F\u043E ' + algolia;
    },
    cs: function cs(algolia) {
      return 'Vyhled\xE1vat s vyu\u017Eit\xEDm slu\u017Eby ' + algolia;
    },
    da: function da(algolia) {
      return 'S\xF8g med ' + algolia;
    },
    de: function de(algolia) {
      return 'Suche \xFCber ' + algolia;
    },
    el: function el(algolia) {
      return '\u0391\u03BD\u03B1\u03B6\u03AE\u03C4\u03B7\u03C3\u03B7 \u03BA\u03B1\u03C4\u03AC ' + algolia;
    },
    en: function en(algolia) {
      return 'Search by ' + algolia;
    },
    es: function es(algolia) {
      return 'B\xFAsqueda por ' + algolia;
    },
    fi: function fi(algolia) {
      return 'Haun tarjoaa ' + algolia;
    },
    fr: function fr(algolia) {
      return 'Recherche par ' + algolia;
    },
    hu: function hu(algolia) {
      return 'Keres\xE9s az ' + algolia + '-val';
    },
    id: function id(algolia) {
      return 'Cari menggunakan ' + algolia;
    },
    it: function it(algolia) {
      return 'Cerca per ' + algolia;
    },
    ja: function ja(algolia) {
      return algolia + '\u3067\u691C\u7D22\u3057\u307E\u3059\u3002';
    },
    ko: function ko(algolia) {
      return algolia + '\uB85C \uAC80\uC0C9';
    },
    nl: function nl(algolia) {
      return 'Zoeken op ' + algolia;
    },
    no: function no(algolia) {
      return 'S\xF8k av ' + algolia;
    },
    pl: function pl(algolia) {
      return 'Szukaj przez ' + algolia;
    },
    pt: function pt(algolia) {
      return 'Pesquisar por ' + algolia;
    },
    'pt-br': function ptBr(algolia) {
      return 'Pesquise por ' + algolia;
    },
    ro: function ro(algolia) {
      return 'C\u0103uta\u021Bi dup\u0103 ' + algolia;
    },
    ru: function ru(algolia) {
      return '\u041D\u0430\u0439\u0442\u0438 \u0432 ' + algolia;
    },
    sk: function sk(algolia) {
      return 'Vyh\u013Ead\xE1va\u0165 pod\u013Ea ' + algolia;
    },
    sv: function sv(algolia) {
      return 'S\xF6k genom ' + algolia;
    },
    th: function th(algolia) {
      return '\u0E04\u0E49\u0E19\u0E2B\u0E32\u0E42\u0E14\u0E22 ' + algolia;
    },
    tr: function tr(algolia) {
      return algolia + '\'ya g\xF6re ara';
    },
    uk: function uk(algolia) {
      return '\u041F\u043E\u0448\u0443\u043A \u0437\u0430 \u0434\u043E\u043F\u043E\u043C\u043E\u0433\u043E\u044E ' + algolia;
    },
    vi: function vi(algolia) {
      return 'T\xECm ki\u1EBFm theo ' + algolia;
    },
    'zh-cn': function zhCn(algolia) {
      return '\u6839\u636E ' + algolia + ' \u641C\u7D22';
    },
    'zh-tw': function zhTw(algolia) {
      return '\u4F7F\u7528 ' + algolia + ' \u641C\u5C0B';
    }
  },
  tags: {
    ar: 'العلامات',
    bg: 'Етикети',
    cs: 'Značky',
    da: 'Mærke',
    el: 'Ετικέτες',
    en: 'Tags',
    es: 'Etiquetas',
    fi: 'Merkit',
    hu: 'Tagek',
    id: 'Tag',
    it: 'Tag',
    ja: 'タグ',
    ko: '태그',
    nl: 'Labels',
    no: 'Stikkord',
    pl: 'Tagi',
    pt: 'Etiquetas',
    ro: 'Etichete',
    ru: 'Теги',
    sk: 'Tagy',
    sv: 'Taggar',
    th: 'ป้ายชื่อ',
    tr: 'Etiketler',
    uk: 'Ярлики',
    vi: 'Thẻ',
    'zh-cn': '标签',
    'zh-tw': '標籤'
  }
};

function setLang(userTranslations, langKey) {
  var associatedLangKey = LOCALES_ASSOCIATIONS[langKey];

  var _loop = function _loop(key) {
    // eslint-disable-next-line no-continue
    if (!TRANSLATIONS.hasOwnProperty(key)) return 'continue';
    var itemTranslation = TRANSLATIONS[key];
    var itemUserTranslation = userTranslations[key] || {};

    var trad = itemUserTranslation[langKey] || itemTranslation[langKey] || itemUserTranslation[associatedLangKey] || itemTranslation[associatedLangKey] || itemUserTranslation.en || // Fallback on english
    itemTranslation.en;

    if (['change_query', 'clear_filters'].indexOf(key) !== -1) {
      trad = '<span class="ais-link ais-' + key.replace(/_/g, '-') + '">' + trad + '</span>';
    }
    if (['nb_results', 'quoted'].indexOf(key) !== -1) {
      trad = function (_trad) {
        return function () {
          for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
            args[_key] = arguments[_key];
          }

          return '<span class="ais-' + key.replace(/_/g, '-') + '">' + _trad.call.apply(_trad, [this].concat(args)) + '</span>';
        };
      }(trad);
    }

    if (typeof trad === 'function') {
      trad = trad.bind(userTranslations);
    }

    userTranslations[key] = trad;
  };

  for (var key in TRANSLATIONS) {
    var _ret = _loop(key);

    if (_ret === 'continue') continue;
  }
}

function loadTranslations(options) {
  setLang(options.translations, (0, _getCurrentLocale2.default)());
}

exports.default = loadTranslations;